@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2003-2014 Free Software Foundation, Inc.
+# Copyright (C) 2003-2015 Free Software Foundation, Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #   - Automake
 #   - Wget
 #   - Git
+#   - XZ Utils
 #
 # By default, it fetches Gnulib as a git submodule.  If you already
 # have a local copy of Gnulib, you can avoid extra network traffic by
@@ -244,6 +245,7 @@ if ! $skip_gnulib; then
       sys_stat
       sys_time
       term-styled-ostream
+      unictype/ctype-space
       unilbrk/ulc-width-linebreaks
       uniname/uniname
       unistd
@@ -348,8 +350,11 @@ if ! $skip_gnulib; then
       stdbool
       stdio
       stdlib
+      stpcpy
+      stpncpy
       strchrnul
       strerror
+      unictype/ctype-space
       unilbrk/ulc-width-linebreaks
       unistr/u8-mbtouc
       unistr/u8-mbtoucr
@@ -394,15 +399,15 @@ fi
 
 # Fetch gettext-tools/misc/archive.dir.tar.
 if ! test -f gettext-tools/misc/archive.dir.tar; then
-  if ! test -f gettext-tools/misc/archive.dir.tar.gz; then
+  if ! test -f gettext-tools/misc/archive.dir.tar.xz; then
     echo "$0: getting gettext-tools/misc/archive.dir.tar..."
-    wget -q --timeout=5 -O gettext-tools/misc/archive.dir.tar.gz-t "ftp://alpha.gnu.org/gnu/gettext/archive.dir-latest.tar.gz" \
-      && mv gettext-tools/misc/archive.dir.tar.gz-t gettext-tools/misc/archive.dir.tar.gz
+    wget -q --timeout=5 -O gettext-tools/misc/archive.dir.tar.xz-t "ftp://alpha.gnu.org/gnu/gettext/archive.dir-latest.tar.xz" \
+      && mv gettext-tools/misc/archive.dir.tar.xz-t gettext-tools/misc/archive.dir.tar.xz
     retval=$?
-    rm -f gettext-tools/misc/archive.dir.tar.gz-t
+    rm -f gettext-tools/misc/archive.dir.tar.xz-t
     test $retval -eq 0 || exit $retval
   fi
-  gzip -d -c < gettext-tools/misc/archive.dir.tar.gz > gettext-tools/misc/archive.dir.tar-t \
+  xz -d -c < gettext-tools/misc/archive.dir.tar.xz > gettext-tools/misc/archive.dir.tar-t \
     && mv gettext-tools/misc/archive.dir.tar-t gettext-tools/misc/archive.dir.tar
   retval=$?
   rm -f gettext-tools/misc/archive.dir.tar-t
@@ -419,7 +424,7 @@ fi
 )
 
 (cd gettext-runtime
- echo "$0: geneating configure in gettext-runtime..."
+ echo "$0: generating configure in gettext-runtime..."
  aclocal -I m4 -I ../m4 -I gnulib-m4
  autoconf
  autoheader && touch config.h.in
@@ -427,7 +432,7 @@ fi
 )
 
 (cd gettext-tools/examples
- echo "$0: geneating configure in gettext-tools/examples..."
+ echo "$0: generating configure in gettext-tools/examples..."
  aclocal -I ../../gettext-runtime/m4 -I ../../m4
  autoconf
  automake --add-missing --copy
@@ -443,9 +448,22 @@ cp -p gettext-runtime/po/en@quot.header gettext-tools/po/en@quot.header
 cp -p gettext-runtime/po/en@boldquot.header gettext-tools/po/en@boldquot.header
 cp -p gettext-runtime/po/insert-header.sin gettext-tools/po/insert-header.sin
 cp -p gettext-runtime/po/remove-potcdate.sin gettext-tools/po/remove-potcdate.sin
+# Those two files might be newer than Gnulib's.
+sed_extract_serial='s/^#.* serial \([^ ]*\).*/\1/p
+1q'
+for file in intl.m4 po.m4; do
+  existing_serial=`sed -n -e "$sed_extract_serial" < "gettext-tools/gnulib-m4/$file"`
+  gettext_serial=`sed -n -e "$sed_extract_serial" < "gettext-runtime/m4/$file"`
+  if test -n "$existing_serial" && test -n "$gettext_serial" \
+        && test "$existing_serial" -ge "$gettext_serial" 2> /dev/null; then
+    :
+  else
+    cp -p "gettext-runtime/m4/$file" "gettext-tools/gnulib-m4/$file"
+  fi
+done
 
 (cd gettext-tools
- echo "$0: geneating configure in gettext-tools..."
+ echo "$0: generating configure in gettext-tools..."
  aclocal -I m4 -I ../gettext-runtime/m4 -I ../m4 -I gnulib-m4 -I libgrep/gnulib-m4 -I libgettextpo/gnulib-m4
  autoconf
  autoheader && touch config.h.in
