@@ -1,5 +1,6 @@
 /* xgettext Perl backend.
-   Copyright (C) 2002-2003, 2006, 2010 Free Software Foundation, Inc.
+   Copyright (C) 2002-2003, 2006, 2010, 2015 Free Software Foundation,
+   Inc.
    Written by Guido Flohr <guido@imperia.net>, 2002-2003
 
    This program is free software: you can redistribute it and/or modify
@@ -36,7 +37,7 @@ extern "C" {
 
 #define SCANNERS_PERL \
   { "perl",             extract_perl,                                   \
-            &flag_table_perl, &formatstring_perl, &formatstring_perl_brace }, \
+            &flag_table_perl, &formatstring_perl, &formatstring_perl_brace, NULL }, \
 
 /* Scan a Perl file and add its translatable strings to mdlp.  */
 extern void extract_perl (FILE *fp, const char *real_filename,
